@@ -1,5 +1,5 @@
 package Mira::View::Floor;
-$Mira::View::Floor::VERSION = '00.07.30';
+$Mira::View::Floor::VERSION = '00.07.31';
 
 use strict;
 use warnings;
@@ -137,7 +137,7 @@ sub template {
             or
             $a->{_number} <=> $b->{_number}
           }
-          (values %{ $archives->{$floor}->{date} })
+          (values %{ $archives->{$floor}->{date}->{$field} })
           ];
         }
 
@@ -168,13 +168,13 @@ sub template {
 
           $page->{next}->{url} = @utids ? "$config->{$floor}->{root}/page/" . ($page_number+1) . "/" : '' ;
           $page->{next}->{url} =~ s{^(.*?):/+|/+}{/}g if ($page->{next}->{url});
-          $page->{next}->{title} = ($page_number+1) if $vars->{next}->{url};
+          $page->{next}->{title} = ($page_number+1) if $page->{next}->{url};
           delete $page->{next} unless $page->{next}->{url};
 
           $page->{prev}->{url} = $page_number == 1 ? '' : "$config->{$floor}->{root}/page/" . ($page_number-1) . "/" ;
           $page->{prev}->{url} = $config->{$floor}->{root} . "/" if $page_number == 2;
           $page->{prev}->{url} =~ s{^(.*?):/+|/+}{/}g if ($page->{prev}->{url});
-          $page->{prev}->{title} = ($page_number-1) if $vars->{prev}->{url};
+          $page->{prev}->{title} = ($page_number-1) if $page->{prev}->{url};
           delete $page->{prev} unless $page->{prev}->{url};
 
           $page->{number} = $page_number;
