@@ -1,5 +1,5 @@
 package Mira::View::Post;
-$Mira::View::Post::VERSION = '00.07.30';
+$Mira::View::Post::VERSION = '00.07.31';
 
 use strict;
 use warnings;
@@ -184,7 +184,7 @@ sub template {
            or
            $a->{_number} <=> $b->{_number}
          }
-         (values %{ $archives->{$floor}->{date} })
+         (values %{ $archives->{$floor}->{date}->{$field} })
          ];
        }
 
